@@ -6,9 +6,11 @@ from .ironclust import IronClustSorter
 from .kilosort import KilosortSorter
 from .kilosort2 import Kilosort2Sorter
 from .kilosort2_5 import Kilosort2_5Sorter
+from .kilosort3 import Kilosort3Sorter
 from .spyking_circus import SpykingcircusSorter
 from .herdingspikes import HerdingspikesSorter
 from .waveclus import WaveClusSorter
+from .yass import YassSorter
 from .combinato import CombinatoSorter
 
 sorter_full_list = [
@@ -20,17 +22,18 @@ sorter_full_list = [
     KilosortSorter,
     Kilosort2Sorter,
     Kilosort2_5Sorter,
+    Kilosort3Sorter,
     SpykingcircusSorter,
     HerdingspikesSorter,
     WaveClusSorter,
+    YassSorter,
     CombinatoSorter
 ]
 
 sorter_dict = {s.sorter_name: s for s in sorter_full_list}
 
 
-
-# generic laucnher via function approach
+# generic launcher via function approach
 def run_sorter(sorter_name_or_class, recording, output_folder=None, delete_output_folder=False,
                grouping_property=None, parallel=False, verbose=False, raise_error=True, n_jobs=-1, joblib_backend='loky',
                **params):
@@ -88,7 +91,7 @@ def run_sorter(sorter_name_or_class, recording, output_folder=None, delete_outpu
                          verbose=verbose, delete_output_folder=delete_output_folder)
     sorter.set_params(**params)
     sorter.run(raise_error=raise_error, parallel=parallel, n_jobs=n_jobs, joblib_backend=joblib_backend)
-    sortingextractor = sorter.get_result()
+    sortingextractor = sorter.get_result(raise_error=raise_error)
 
     return sortingextractor
 
@@ -486,6 +489,43 @@ def run_kilosort2_5(*args, **kwargs):
     return run_sorter('kilosort2_5', *args, **kwargs)
 
 
+def run_kilosort3(*args, **kwargs):
+    """
+    Runs kilosort3 sorter
+
+    Parameters
+    ----------
+    *args: arguments of 'run_sorter'
+        recording: RecordingExtractor
+            The recording extractor to be spike sorted
+        output_folder: str or Path
+            Path to output folder
+        delete_output_folder: bool
+            If True, output folder is deleted (default False)
+        grouping_property: str
+            Splits spike sorting by 'grouping_property' (e.g. 'groups')
+        parallel: bool
+            If True and spike sorting is by 'grouping_property', spike sorting jobs are launched in parallel
+        verbose: bool
+            If True, output is verbose
+        raise_error: bool
+            If True, an error is raised if spike sorting fails (default). If False, the process continues and the error
+            is logged in the log file
+        n_jobs: int
+            Number of jobs when parallel=True (default=-1)
+        joblib_backend: str
+            joblib backend when parallel=True (default='loky')
+    **kwargs: keyword args
+        Spike sorter specific arguments (they can be retrieved with 'get_default_params('kilosort3')
+
+    Returns
+    -------
+    sortingextractor: SortingExtractor
+        The spike sorted data
+    """
+    return run_sorter('kilosort3', *args, **kwargs)
+
+
 def run_spykingcircus(*args, **kwargs):
     """
     Runs spykingcircus sorter
@@ -624,7 +664,7 @@ def run_combinato(*args, **kwargs):
         joblib_backend: str
             joblib backend when parallel=True (default='loky')
     **kwargs: keyword args
-        Spike sorter specific arguments (they can be retrieved with 'get_default_params('waveclus')
+        Spike sorter specific arguments (they can be retrieved with 'get_default_params('combinato')
 
     Returns
     -------
@@ -632,3 +672,40 @@ def run_combinato(*args, **kwargs):
         The spike sorted data
     """
     return run_sorter('combinato', *args, **kwargs)
+
+
+def run_yass(*args, **kwargs):
+    """
+    Runs YASS sorter
+
+    Parameters
+    ----------
+    *args: arguments of 'run_sorter'
+        recording: RecordingExtractor
+            The recording extractor to be spike sorted
+        output_folder: str or Path
+            Path to output folder
+        delete_output_folder: bool
+            If True, output folder is deleted (default False)
+        grouping_property: str
+            Splits spike sorting by 'grouping_property' (e.g. 'groups')
+        parallel: bool
+            If True and spike sorting is by 'grouping_property', spike sorting jobs are launched in parallel
+        verbose: bool
+            If True, output is verbose
+        raise_error: bool
+            If True, an error is raised if spike sorting fails (default). If False, the process continues and the error
+            is logged in the log file
+        n_jobs: int
+            Number of jobs when parallel=True (default=-1)
+        joblib_backend: str
+            joblib backend when parallel=True (default='loky')
+    **kwargs: keyword args
+        Spike sorter specific arguments (they can be retrieved with 'get_default_params('yass')
+
+    Returns
+    -------
+    sortingextractor: SortingExtractor
+        The spike sorted data
+    """
+    return run_sorter('yass', *args, **kwargs)
